%bcond_with bootstrap

Summary:       Library to render fonts
Name:          freetype
Version:       2.13.1
Release:       11%{?dist}
License:       FTL or GPLv2+
URL:           https://freetype.org/
Source0:       https://sourceforge.net/projects/freetype/files/freetype2/%{version}/%{name}-%{version}.tar.xz
Source1:       https://sourceforge.net/projects/freetype/files/freetype-docs/%{version}/freetype-doc-%{version}.tar.xz
Source2:       https://sourceforge.net/projects/freetype/files/freetype-demos/%{version}/ft2demos-%{version}.tar.xz
Patch0001: https://gitlab.freedesktop.org/freetype/freetype/-/commit/f42ce25563b73fed0123d18a2556b9ba01d2c76b.patch
Patch0002: https://gitlab.freedesktop.org/freetype/freetype/-/commit/17545d4bf72175a8ea8020dcbd4d462234d2b5d0.patch
Patch0003: https://gitlab.freedesktop.org/freetype/freetype/-/commit/2a790a9f4937c3950028bd3de29e63c6b0d419ce.patch
# Enable subpixel rendering
Patch3000:  freetype-2.3.0-enable-spr.patch

BuildRequires: gcc make 
BuildRequires: libX11-devel libpng-devel zlib-devel
BuildRequires: bzip2-devel brotli-devel
%if %{without bootstrap}
BuildRequires: harfbuzz-devel
%endif
Provides:      %{name}-bytecode
Provides:      %{name}-subpixel

%description
FreeType is a freely available software library to render fonts.
It is written in C, designed to be small, efficient, highly customizable,
and portable while capable of producing high-quality output (glyph images)
of most vector and bitmap font formats.


%package devel
Summary:       FreeType development libraries and header files
Requires:      %{name} = %{version}-%{release}
Requires:      pkgconf

%description devel
The package includes libraries and header files for FreeType.


%package demos
Summary:       FreeType demos
Requires:      %{name} = %{version}-%{release}

%description demos
The package includes utilities showing various capabilities of the FreeType library.


%prep
%setup -q -b 1 -a 2
%autopatch -p1


%build
%configure --disable-static \
           --with-zlib=yes \
           --with-bzip2=yes \
           --with-png=yes \
           --enable-freetype-config \
           --with-brotli=yes \
%if %{without bootstrap}
           --with-harfbuzz=yes
%else
           --with-harfbuzz=no
%endif

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' builds/unix/libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' builds/unix/libtool
%make_build
# Build demos
pushd ft2demos-%{version}
make TOP_DIR=".."
popd


%install
%make_install
#for ft2demos
for ftdemo in ftbench ftdump ftlint ftvalid ftdiff ftgamma ftgrid ftmulti ftstring ftview; do
    builds/unix/libtool --mode=install install -m 755 ft2demos-%{version}/bin/$ftdemo $RPM_BUILD_ROOT/%{_bindir}
done
for ftdemo in ftbench ftdump ftlint ftvalid ftdiff ftgamma ftgrid ftmulti ftstring ftview; do
    builds/unix/libtool --mode=install install -m 644 ft2demos-%{version}/man/${ftdemo}.1 $RPM_BUILD_ROOT/%{_mandir}/man1
done

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la


%files
%license LICENSE.TXT docs/FTL.TXT docs/GPLv2.TXT
%doc README
%{_libdir}/libfreetype.so.*


%files devel
%doc docs/CHANGES docs/formats.txt docs/ft2faq.html
%doc docs/design docs/glyphs docs/reference docs/tutorial
%dir %{_includedir}/freetype2
%{_includedir}/freetype2/*
%{_libdir}/libfreetype.so
%{_libdir}/pkgconfig/freetype2.pc
%{_bindir}/freetype-config
%{_datadir}/aclocal/freetype2.m4
%{_mandir}/man1/freetype-config.1.gz

%files demos
%doc ChangeLog README
%{_bindir}/ft*
%{_mandir}/man1/ft*


%changelog
* Wed Jan 15 2025 Tracker Robot <trackbot@opencloudos.tech> - 2.13.1-11
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] 2a790a9f4937c3950028bd3de29e63c6b0d419ce.patch: [cff, truetype] Always set up default variable instance.

* Tue Jan 14 2025 Tracker Robot <trackbot@opencloudos.tech> - 2.13.1-10
- [Type] other
- [DESC] Apply patches from rpm-tracker
- [Performance] 17545d4bf72175a8ea8020dcbd4d462234d2b5d0.patch: Avoid n^2 scanning for binary data.

* Tue Jan 14 2025 Tracker Robot <trackbot@opencloudos.tech> - 2.13.1-9
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] f42ce25563b73fed0123d18a2556b9ba01d2c76b.patch: [colr] Ensure enough bytes for PaintColrLayers

* Mon Dec 23 2024 Miaojun Dong <zoedong@tencent.com> - 2.13.1-8
- Non-boostrap build and build with harfbuzz 8.1.1-6.

* Thu Dec 19 2024 Miaojun Dong <zoedong@tencent.com> - 2.13.1-7
- Bootstrap build to avoid requiring harfbuzz for harfbuzz building.

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.13.1-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.13.1-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.13.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 24 2023 rockerzhu <rockerzhu@tencent.com> - 2.13.1-3
- Non-boostrap build and build with harfbuzz 8.1.1.

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 2.13.1-2
- Bootstrap build to avoid requiring harfbuzz for harfbuzz building.

* Fri Jul 28 2023 rockerzhu <rockerzhu@tencent.com> - 2.13.1-1
- Update to 2.13.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.12.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.12.1-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Jun 17 2022 rockerzhu <rockerzhu@tencent.com> - 2.12.1-1
- Initial build
